==> paraview_4.1.0+dfsg+1.orig.tar.xz: ParaView-v4.1.0/Qt/Components/pqSGPluginManager.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqSGPluginManager.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef __pqSGPluginManager_h
#define __pqSGPluginManager_h

#include "pqComponentsModule.h"
#include <QObject>

/// pqSGPluginManager is the central class that orchestrates the behaviour of
/// this co-processing plugin.
class PQCOMPONENTS_EXPORT pqSGPluginManager : public QObject
{
  Q_OBJECT
  typedef QObject Superclass;
public:
  pqSGPluginManager(QObject* parent=0);
  ~pqSGPluginManager();

  /// Methods used to shartup and shutdown the plugin.
  void startup();

  /// Methods used to shartup and shutdown the plugin.
  void shutdown();

  /// Get the name of the writers menu from the concrete subclass.
  virtual const char* getWritersMenuName() = 0;

  /// Get the Qt name of the writers menu from the concrete subclass.
  virtual const char* getObjectMenuName() = 0;

private:
  pqSGPluginManager(const pqSGPluginManager&); // Not implemented.
  void operator=(const pqSGPluginManager&); // Not implemented.
};

#endif

==> paraview_5.4.1+dfsg3.orig.tar.xz: ParaView-v5.4.1/Qt/Components/pqSGPluginManager.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqSGPluginManager.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqSGPluginManager_h
#define pqSGPluginManager_h

#include "pqComponentsModule.h"
#include <QObject>

/**
* pqSGPluginManager is the central class that orchestrates the behaviour of
* this co-processing plugin.
*/
class PQCOMPONENTS_EXPORT pqSGPluginManager : public QObject
{
  Q_OBJECT
  typedef QObject Superclass;

public:
  pqSGPluginManager(QObject* parent = 0);
  ~pqSGPluginManager();

  /**
  * Methods used to shartup and shutdown the plugin.
  */
  void startup();

  /**
  * Methods used to shartup and shutdown the plugin.
  */
  void shutdown();

  /**
  * Get the name of the writers menu from the concrete subclass.
  */
  virtual const char* getWritersMenuName() = 0;

  /**
  * Get the Qt name of the writers menu from the concrete subclass.
  */
  virtual const char* getObjectMenuName() = 0;

private:
  Q_DISABLE_COPY(pqSGPluginManager)
};

#endif
